MemoryFs

Struct MemoryFs 

pub struct MemoryFs { /* private fields */ }
MemoryFs is a simple in-memory filesystem that can be used for testing purposes.

It implements the RemoteFs trait.

The MemoryFs is instantiated providing a orange_trees::Tree which contains the filesystem data.

When reading or writing files, the MemoryFs will use the orange_trees::Tree to store the data.

You can easily create the MemoryFs using the MemoryFs::new method, providing the tree. Use the node! macro to create the tree or use the orange_trees crate to create it programmatically.

The tree contains nodes identified by a PathBuf and a value of type Inode. Every path passed to the client must be absolute; the tree root is /.

Implementations

Source

impl MemoryFs

pub fn new(tree: FsTree) -> Self

Create a client backed by tree.

uid/gid default to 0 for every file until MemoryFs::with_get_uid or MemoryFs::with_get_gid is used to override them.

Examples
use std::path::PathBuf;

use remotefs::fs::UnixPex;
use remotefs_memory::{Inode, MemoryFs, Node, Tree, node};

let tree = Tree::new(node!(
    PathBuf::from("/"),
    Inode::dir(0, 0, UnixPex::from(0o755))
));
let client = MemoryFs::new(tree);
pub fn with_get_uid<F>(self, get_uid: F) -> Self
where F: Fn() -> u32 + Send + Sync + 'static,

Override the closure used to fill the uid of newly created files.

Examples
use std::path::PathBuf;

use remotefs::fs::UnixPex;
use remotefs_memory::{Inode, MemoryFs, Node, Tree, node};

let tree = Tree::new(node!(
    PathBuf::from("/"),
    Inode::dir(0, 0, UnixPex::from(0o755))
));
let client = MemoryFs::new(tree).with_get_uid(|| 1000);
pub fn with_get_gid<F>(self, get_gid: F) -> Self
where F: Fn() -> u32 + Send + Sync + 'static,

Override the closure used to fill the gid of newly created files.

Examples
use std::path::PathBuf;

use remotefs::fs::UnixPex;
use remotefs_memory::{Inode, MemoryFs, Node, Tree, node};

let tree = Tree::new(node!(
    PathBuf::from("/"),
    Inode::dir(0, 0, UnixPex::from(0o755))
));
let client = MemoryFs::new(tree).with_get_gid(|| 1000);