pub struct MemoryFs { /* private fields */ }Expand description
MemoryFs is a simple in-memory filesystem that can be used for testing purposes.
It implements the RemoteFs trait.
The MemoryFs is instantiated providing a orange_trees::Tree which contains the filesystem data.
When reading or writing files, the MemoryFs will use the orange_trees::Tree to store the data.
You can easily create the MemoryFs using the MemoryFs::new method, providing the tree.
Use the node! macro to create the tree or use the orange_trees crate to create it programmatically.
The tree contains nodes identified by a PathBuf and a value of type Inode.
Every path passed to the client must be absolute; the tree root is /.
Implementations
Sourceimpl MemoryFs
impl MemoryFs
Sourcepub fn new(tree: FsTree) -> Self
pub fn new(tree: FsTree) -> Self
Create a client backed by tree.
uid/gid default to 0 for every file until
MemoryFs::with_get_uid or MemoryFs::with_get_gid is used to
override them.
Examples
Sourcepub fn with_get_uid<F>(self, get_uid: F) -> Self
pub fn with_get_uid<F>(self, get_uid: F) -> Self
Override the closure used to fill the uid of newly created files.
Examples
Sourcepub fn with_get_gid<F>(self, get_gid: F) -> Self
pub fn with_get_gid<F>(self, get_gid: F) -> Self
Override the closure used to fill the gid of newly created files.
Examples